---
title: Evolving MUI's core values and behaviors
description: After significant growth, we united as a team to rediscover the values that underpin our shared success.
date: 2023-09-26T00:00:00.000Z
authors: ['mikailaread']
tags: ['Company']
manualCard: true
---

## Why we chose to revise our core values

Material UI was created in 2014 to grow and serve a community—from developers to designers, then MUI was founded in 2019, our core mission has always been to enable others to create incredible user experiences with unrivaled speed and ease.

Along the way, we embraced certain core principles that guided our ways of working—how we think, act, and innovate have always been grounded in fulfilling the best interests of our community.

In 2019, these became formalized in our first-ever company values: user obsession, excellence, transparency, freedom, and autonomy.

Needless to say, we've seen significant growth since then: both for the company and its products, as well as the broader community surrounding us.

That's why we wanted to take a moment to honor the values that led us to where we are today, and share how we've reshaped them to be an even more powerful force behind MUI's next phase of growth. 🚀

## How we approached our values revision

Company values show up in some facet of all our roles every day, whether we're evaluating different ideas, making tough decisions, or determining the biggest priorities.

That's why it's so critical to ensure company values are actionable and authentic—that they are easily understood and truly shared by every MUIer.

To make that happen, we decided to engage the whole company in a series of discovery and reflection exercises. 🔍

This way, any changes to the company values—along with the language used to express them—would accurately reflect the values shared by our team. Here's how we did it! 👇

<img alt="A collage of slides from the values discovery exercise kickoff." src="/static/blog/2023-mui-values/good-values.png" width="2400" height="1680" loading="lazy" />

## Stage one: discovery questions

Kicking off, everyone was invited to answer 10 questions via an asynchronous survey.

The purpose of this portion was to get a picture of how the existing values were being perceived and actioned throughout the company from day to day.
It was also to give people an opportunity to express what they felt may be _missing_ and important to include for our future success.

We asked people to reflect on how accurately they felt each value described our internal culture; what they felt our company cared deeply about and why; what is utterly unique about us as a team; and more. 🤔💭

<img alt="A screenshot of the intro page to our discovery survey." src="/static/blog/2023-mui-values/values-survey.png" width="2400" height="2340" loading="lazy" />

Then, using keyword and sentiment analysis, we captured clear themes in experience and common language used to describe our culture.
I presented this back to the team via recorded video presentation, inviting reactions and further dialogue in the open of our Slack workspace.

<img alt="A screenshot of a video message in our internal Slack revealing themes from the survey." src="/static/blog/2023-mui-values/themes-video.png" width="2400" height="1500" loading="lazy" />

## Stage two: workshop

At the next stage, folks came together for a synchronous workshop.
(This was completely voluntary, but I'm proud to say we had major representation from all different corners and levels of the company!)

The purpose of this workshop was to pinpoint the _most_ critical mindsets and behaviors that we felt underpinned the company's success at scale.

Broadly speaking, everyone was asked to consider:

1. what mindsets and behaviors we should actively preserve and encourage as we scale—these are our superpowers and biggest differentiators. They're the stuff that makes us "us." 💚

2. what mindsets and behaviors should we actively discourage, even punish—these are the biggest threats to our desired culture. They're the things we would never tolerate, maybe even at the cost of a customer. 🛑

We used a shared FigJam board to brainstorm together against a timer, and repeated the process for different core questions.

Once we'd generated a wonderfully full board, we took a pause to review the contributions.
We upvoted cards that really stood out and resonated with us as individuals.

Finally, we organized all of these cards into little clusters based on relatedness, and started to identify their underlying values and themes.

We came up with a list of words that we felt best encapsulated each cluster. This became our values "shortlist."

<img alt="description" src="/static/blog/2023-mui-values/figjam-board.png" width="2400" height="1000" loading="lazy" />

## Stage three: transforming the shortlist

36\. That's how many words surfaced in our workshop as potential values—or at least, as words to inspire the copywriting process.

Narrowing down the shortlist gave us a chance to both find _and_ stress-test the strongest recurring themes. 🧪

To do this, we immediately eliminated [what Patrick Lencioni calls "permission-to-play" values](https://www.youtube.com/watch?v=bNRn6FimzoU).
These are the things as basic as showing respect, which might be _valuable_ to a great team culture and performance, but aren't exactly _exciting_ or _measurable_.
They're simply the minimum required standard of behavior to work together.

We also started striking out anything that could not clearly be expressed _as an action._

It's [what Simon Sinek was talking about](https://www.youtube.com/watch?v=IQuYzXWXDqI) when he said "honesty is not a value."
If there was not a clear and natural way to transform something into an action or provide examples of how it would be lived in our specific workplace, it was out. 🙅

Success!

We narrowed the list down from 36 to _just six._

Now it was time to transform these six words into actionable phrases to inspire the very actions we want to see championed on a daily basis.

## Stage four: pitching the 'PACT'

All of the above and more influenced what's now referred to as our team "pact." (You'll see why.)

But before we get there, I want to share a few examples of phrases that didn't wind up being a part of the pitch and why.

Finding the right phraseology started with carefully reviewing _all_ team inputs.
As I had a unique vantage point of all those inputs, I began to jot down phrases that effectively pulled from them _all_ and led with _action verbs._ 🕸️💪

Things like "build in the open" made an appearance, but felt too limited.
There was so much more we wanted to capture in the enduring theme of transparency, why it matters to us, and how we show it.

Other phrases included "own your impact" and "maximize flexibility," but these, again, felt too limited and also generic.

In short, they weren't right.

Fortunately, this helped us find the ones that **\***are.**\*** 👏

I presented a video presentation to our team, pitching this set of values and providing another opportunity for feedback and shaping.

You can <a href="https://mui-org.notion.site/Values-behaviors-d3a1e1c60e2a4c0782f770cceada54bd#09dc19a420504a3090dc4fbe6a68a543">watch the "reveal" video for yourself here</a>! 🎬👀

## Stage five: revising and finalizing

Since we work asynchronously at MUI, we like to leave a good window of time for peers to properly review, digest, and offer thoughtful feedback.

Since we place such a high value on quality and accuracy, we didn't want to rush this process, and so we extended our deadline for delivery.

As we approached the finish line, I collaborated closely with our CEO and co-founder, Olivier. 🙋

Our goal was to ensure that the final values not only reflected our team and company culture but, most importantly, that they could be integrated effectively into our company's operations and performance expectations.

And we believe we've achieved just that! Here they come... 🥁

## What are MUI's core values today?

Our core four are:

**P** — Put community first. "We never lose sight of who we're serving and why." 💙

**A** — Avoid bureaucracy. "We're so not corporate—and we like it that way." 🚫

**C** — Chase better. "We're driven by an unending desire to improve." 🌱

**T** — Trust and deliver together. "We cultivate unity as the core of achievement." 🚀

To delve deeper into the meaning of each value and what it looks like in practice, you can also check out our handbook: <a href="https://mui-org.notion.site/Values-behaviors-d3a1e1c60e2a4c0782f770cceada54bd">Values & Behaviors.</a>

In it, we offer concrete examples of each core value and explicitly address tensions folks may encounter in trying to live them out.

<img alt="description" src="/static/blog/2023-mui-values/notion-values-page.png" width="2400" height="2340" loading="lazy" />

## What do they mean?

### Put community first

Put community first underscores our unwavering commitment to anchoring every decision in the best interests of the collective.

By "community", we refer to both the user base that we serve and the team that propels us forward.

The litmus test for any decision at MUI begins with a simple yet profound query: How does this contribute to our community's progress? We prioritize the needs and feedback of the community, and invest our efforts toward what will bring the greatest benefit to the greatest number of people.

Putting community first means also that we consciously forge connections.
We recognize that deeper mutual understanding fuels collective progress.
By investing in relationships, we enhance collaboration, foster productive teamwork, and create a work environment that's as enjoyable as it is efficient.

### Avoid bureaucracy

Avoid bureaucracy is all about staying lean, open, and people-first.
One of the core beliefs we hold at MUI is that people are the best experts on when, where, and how they will do their best work.

We actively champion this principle by fostering an environment of unparalleled flexibility and autonomy, which serves as a bedrock for sustained excellence.

Our dedication to shunning bureaucracy manifests in tangible ways—for instance, most of our communications and work are in the open.
We default to transparency as much as possible.

We don't over-structure, or add processes or hierarchies where they aren't needed.
To introduce a process, we need to clearly show how it makes things 10x better than the current approach.

We don't have lengthy approvals processes or a formalized chain of command; instead we collaborate as a tight-knit network where anyone can ask about and contribute to anything.

### Chase "better"

Chase "better" is all about consistently improving and developing in all aspects of our work as well as raising the bar for quality.

It addresses our attitude to risk, feedback, and setbacks too.
Genuine innovation demands a fearless embrace of the uncharted, even if it entails a touch of chaos.

We want to create the exceptional—not the "good enough."
So we tend to prioritize quality over speed.
This doesn't mean we wait for things to be perfect before releasing them.

On the contrary, "chase better" encourages us all to make small changes and incremental improvements again and again.

It also encourages us to venture into unfamiliar territory and get out of our comfort zones in the name of growth.

### Trust and deliver together

Trust and deliver together is all about building trust, alignment, and shared responsibility.

It reflects our commitment to following through and working as one force to solve problems and create value.

In practice, this looks like: doing what we say we will; proactively communicating progress; adapting swiftly to changing circumstances and demands to guarantee success; and readily offering or seeking help when necessary.

It's also about strategic collaboration, and being able to recognize and enlist one another for our unique strengths toward shared goals.

"Trust and deliver together" reflects our firm belief that together, our combined efforts are stronger and more impactful than what we can achieve individually.

## How do we reinforce values across the org?

Articulating company values and operationalizing them are two different things.

To ensure values don't become mere writing on the wall at MUI, we've purposefully woven them into internal processes and programs.
We surface them often and stay attuned to how people are perceiving and connecting to them through different initiatives. 🌠🔦

For example, before you even join MUI, you'll answer carefully chosen questions in your interviews.
This helps us understand how well you align with our company values and how you might contribute to enhancing them and our culture. 📝

On a day-to-day level, values show up everywhere.
They're referenced in discussions and deliberations related to our work.
We explicitly state how they directly influence our strategies and plans within our documents.
Exemplifying core values is also a condition for promotion here and therefore a topic in performance and development conversations. 🆙

As a fun way to reinforce values and show team gratitude, we've also created #Thanks-And-Praise Thursdays—a dedicated Slack channel that prompts us every Thursday to think about who we could recognize for championing core values and behaviors.

Our design team even created custom illustrations and Slack emojis to make highlighting values-driven moments as simple as just a few clicks.
(Thank you Gerda, Victor, and Danilo!) 🙏

<img alt="Custom-designed illustrations for each MUI company value." src="/static/blog/2023-mui-values/values-illustrations.png" width="2400" height="1000" loading="lazy" />

## When might the values change again?

MUI's first values were set forth by our founders during the earliest stages of the company, with the recognition that they would evolve alongside our company's growth.

Those values remain foundational to the ways we work and engage.
It's quite evident how these have been represented in new ways within the core four.

But we don't expect these to last forever, either.

As we continue to progress through new stages of development in the coming years, we intentionally plan to review our values and continue cultivating a values-driven culture.

## Join the team

Do these values resonate with you? Perhaps you'd like to be a part of shaping the future of MUI.

[Visit our careers page now!](/careers/) 🏃💨
