# Designer

<p class="description">Design is critical to our success. We're looking for skills that complement those of our Lead Designer. You'll help to design the tools that enable our audience to build outstanding-looking UIs.</p>

## The company

MUI's story began in 2014 with Material UI, the most successful React implementation of Google's Material Design.
Today, Material UI stands as one of the most popular open-source libraries on GitHub and has paved the way for the fully-fledged startup known as MUI (founded in 2019), which now boasts an ever-expanding ecosystem of React UI products.
We're a company of 35+ people as of early 2024, and we're growing.

## The products

MUI is best known for our flagship product, Material UI—but this is just one of three core component libraries we maintain.
Base UI is our headless component library, and Joy UI is a sister library to Material UI that implements our own in-house Joy Design system.
We also host Design Kits and pre-built Templates.

Beyond the core libraries, MUI X offers advanced components like the Data Grid, Date and Time Pickers, and Charts, for more complex user interactions and data visualization needs.

We're also making ambitious moves to incorporate our full suite of components into Toolpad, a low-code admin builder tool for assembling full-stack apps faster than ever.

Learn more about MUI's products in this blog post: [An introduction to the MUI ecosystem](https://mui.com/blog/mui-product-comparison/).

## The culture

MUI is a fully remote company with a team that spans the globe.
The majority of our work is asynchronous, and we rely on written communication to collaborate.
We're radically transparent: nearly all of our work happens in public.
Each contributor has the freedom to decide how and when they work, and that work is primarily self-directed: it's your responsibility to define and complete your own tasks in a timely manner.

For additional details about the culture, you can check our [careers](https://mui.com/careers/) and [about](https://mui.com/about/) pages and also our [public Handbook](https://mui-org.notion.site/Handbook-f086d47e10794d5e839aef9dc67f324b).

## Why we're hiring

Material UI started as an open-source project.
Over time, the audience and usage grew considerably, and some of the library's early contributors became full-time maintainers.
A company was incorporated to support this growth, and more recently [was rebranded from Material UI to MUI](https://mui.com/blog/material-ui-is-now-mui/).
The new brand was fundamental to set the stage for MUI to become larger than Material Design, which was something we were already doing.
Currently, we have five main projects that are not at all related to MD:

- [MUI Core](https://mui.com/core/):
  - [Base UI](https://mui.com/base-ui/getting-started/): the unstyled version of the components.
  - [MUI System](https://mui.com/system/getting-started/): our most recent take on styling for React components.
  - [MUI Joy (working title)](https://github.com/mui/material-ui/discussions/29024): a second design system as an alternative to Material Design.
- [MUI X](https://mui.com/x/): as mentioned, a growing set of advanced components.
  Today, the flagship is the [Data Grid](https://mui.com/x/react-data-grid/), a game-changing component for presenting large amounts of data, which integrates perfectly with MUI Core.
- Toolpad: a very recent endeavor aimed at exploring how our users can visually create apps 10x faster with the power of low-code and the flexibility of pro-code.

We also know, especially due to [our annual Developer Survey](https://mui.com/blog/2021-developer-survey-results/), that design quality plays a huge part when developers are considering component library options.
Therefore, we need to grow the design team to help us push these initiatives further.

## The role

Some criteria for applying to this role:

- **Location**: fully remote (preference for UTC-6 to UTC +3).
- **Type of work**: full-time (as a contractor or employee, [depending primarily on location](https://mui-org.notion.site/Hiring-FAQ-64763b756ae44c37b47b081f98915501)).
- **Level**: [IC3 or above](https://mui-org.notion.site/Design-levels-aa01996ca7e0481e80479ad47c8f28a4).

We need someone experienced enough to help two different teams with hard problems.
You'll be responsible for ensuring that the Toolpad and MUI X teams have spot-on design and product work.
Given that each product is at a different stage, at this moment we believe that one person is enough to oversee the design function for both teams.
You'll have the freedom, trust, and help you need to balance and tackle all the work.
You'll also be the second designer of a growing design team, so we'll also need your help to shape this growth.

### Here are a few initiatives you might work on

- Help design the first version of Toolpad, from early strategy to its look and feel.
- Evolve and refine the Data Grid UX for features such as filtering, column pinning, row editing, and more.
- Help set the bar higher for MUI X documentation, from visual design to copywriting.
- Support the design team growth by promoting design/product culture, and hiring new members.

### You might fit for this role if you

- See yourself as a generalist designer, tackling problems ranging from strategic thinking to execution. (More insight in the [first draft of our design philosophy](https://mui-org.notion.site/Design-philosophy-bdbef60d6fad4134a43870df3e452ebc), available in our public Handbook).
- Have excellent visual and interaction design skills.
- Consider yourself a great communicator, both written and verbal.
  Designers are key players when it comes to creating alignment and shared understanding, whether with internal or external stakeholders.
- Feel comfortable around code and git (we use GitHub).
  Developers are MUI's main audience, so it's very important to experience our technology for yourself, to empathize with our users.
  You should be capable of tweaking JSX and CSS, ensuring that your designs are implemented with the highest fidelity.
  But don't worry, you'll always have the support of your teams' developers.

Previous experience with design systems would be great but is not required.

## Benefits and compensation

We offer competitive compensation, aligned with your profile and location.
We're ready to pay top market rates for a designer that can significantly push the mission forward.
Other perks are described on [the careers page](https://mui.com/careers/#perks-and-benefits).

## How to apply

[Apply now for this position 📮](https://jobs.ashbyhq.com/MUI/__ID__/application?utm_source=ZNRrPGBkqO).

## What happens next?

We start by screening applications, looking for designers that showcase the desired skills and experience.
If your application stands out, we'll contact you for a get-to-know conversation, where we'll meet each other.

If that goes well, you'll be invited to up to four additional conversations, those being:

- A walkthrough of one or two selected projects that you believe demonstrate [comparable experience.](https://articles.uie.com/ux-hiring-lets-talk-about-comparable-experience/)
- A chat with one of the product managers or engineers that you will work closely with.
- A chat with one of MUI's founders.
- A possible follow-up chat if we missed addressing anything relevant in the previous conversations.

All these conversations will be 1:1 and over video chat.
Please ask as many questions as you wish throughout the whole process, it's a two-way discussion.
If you happen to need additional conversations as well, feel free to ask; we'll be happy to schedule them.
Lastly, please note that we're unable to offer individual feedback during the initial screening process, as we're a small team and don't have the bandwidth to do so.

We look forward to hearing from you! ☺️

Don't meet every requirement?
Apply anyway!
Research shows that certain folks are less likely to apply for a role than others [unless they meet 100%](https://hbr.org/2014/08/why-women-dont-apply-for-jobs-unless-theyre-100-qualified) of the outlined qualifications.
If this role excites you, we want to hear from you.
We'd love for you to share the unique skills, passion, and experience you could bring to MUI.
