# Developer Advocate / Content Engineer

<p class="description">You will strategize and implement educational initiatives from end to end to help developers build better UIs, faster.</p>

## Details of the role

- **Location**: Remote (strong preference for UTC-5 to UTC+2 in North America or Europe).
- **Type of work**: Full-time (contractor or employee [depending on circumstances](https://mui-org.notion.site/Hiring-FAQ-64763b756ae44c37b47b081f98915501#494af1f358794028beb4b7697b5d3102)).
- **Level**: [IC4 or above](https://mui-org.notion.site/Leveling-at-MUI-5c30f9bfe65149d697f346447cef9db1).
- We're a **remote** company, we prefer asynchronous communication over meetings.

## The company

MUI's story began in 2014 with Material UI, the most successful React implementation of Google's Material Design.
Today, Material UI stands as one of the most popular open-source libraries on GitHub and has paved the way for the fully-fledged startup known as MUI (founded in 2019), which now boasts an ever-expanding ecosystem of React UI products.
We're a company of 35+ people as of early 2024, and we're growing.

## The products

MUI is best known for our flagship product, Material UI—but this is just one of three core component libraries we maintain.
Base UI is our headless component library, and Joy UI is a sister library to Material UI that implements our own in-house Joy Design system.
We also host Design Kits and pre-built Templates.

Beyond the core libraries, MUI X offers advanced components like the Data Grid, Date and Time Pickers, and Charts, for more complex user interactions and data visualization needs.

We're also making ambitious moves to incorporate our full suite of components into Toolpad, a low-code admin builder tool for assembling full-stack apps faster than ever.

Learn more about MUI's products in this blog post: [An introduction to the MUI ecosystem](https://mui.com/blog/mui-product-comparison/). (This is also the kind of content you might create!)

## The culture

MUI is a fully remote company with a team that spans the globe.
The majority of our work is asynchronous, and we rely on written communication to collaborate.
We're radically transparent: nearly all of our work happens in public.
Each contributor has the freedom to decide how and when they work, and that work is primarily self-directed: it's your responsibility to define and complete your own tasks in a timely manner.

Learn more about what we value as an organization: [Evolving MUI's core values and behaviors](https://mui.com/blog/2023-mui-values/).

## Why we're hiring

MUI's DevEx program is currently maintained by a "team" of one, and that one person devotes the majority of their time to documentation and written technical content.

Our users [consistently rank documentation](https://mui.com/blog/2021-developer-survey-results/#what-are-your-most-important-criteria-for-choosing-a-ui-library) as one of the most important factors in deciding whether or not to build with our products, and many users express dissatisfaction with the rather steep learning curve that they face when onboarding.

With that in mind, we're looking to grow the DevEx team, with a second individual who can dig deep into improving the documentation experience and expand our output of educational materials, to ease the learning curve, improve the product, and inspire users with great examples of what's possible with our libraries.

## The role

MUI's Developer Experience program consists of three key pillars—Education, Documentation, and Community—which all contribute to the company's primary goal: to help developers build beautiful user interfaces quickly and efficiently.

As our next Developer Advocate, you will focus your efforts on the creation of educational content and documentation initiatives.
You may also need to work on projects related to product DX and documentation engineering depending on where the biggest improvement opportunities are.
This role isn't centered on public speaking or community relations but this might be needed from time to time.

You will also have frequent opportunities to shape the DevEx roadmap and contribute to product roadmaps by gathering feedback from the community and voicing the needs of users.

Check out [The Radiating Circles of DX](https://dx.tips/circles) to better understand how we think about this role.
From the perspective of that framework, you would pioneer the Content layer while contributing to the Docs and Product layers depending on where the problem is best solved (the closer to the root the better).

### Key responsibilities

Depending on the day, you'll:

- Create inspiring educational materials (demo apps, how-to guides, integration examples, tutorials) for devs of all skill levels
- Seek out and implement improvements to the documentation
- Contribute to the docs infrastructure, docs UX, or directly to the product depending on where the problem is best solved (the closer to the root the better).
- Engage with the community and gather feedback for product teams
- Serve as the "voice" of the company through social media, conferences, and events

For the right candidate:

- Lead the Developer Experience team; work with the company leadership to construct and execute a hiring plan to grow the team

### Tasks and initiatives you might take on

- Create tutorials to ease the migration from competitor products
- Improve the Algolia search experience
- Own community GitHub issues or PRs related to developer experience
- Build example apps with MUI products and create how-to content around them
- Research and write case studies
- Overhaul the [Showcase](https://mui.com/material-ui/discover-more/showcase/)
- Revamp the company blog infrastructure to empower less technical teammates to contribute (for example HR)
- Contribute to integrations with other popular libraries and frameworks
- Create a learning section in the documentation for hybrid written and video tutorials

## Who we're looking for

### Required

- You're passionate about UI development
- You're excited about helping engineers build amazing UIs
- You're highly empathetic
- Fluent written and spoken English skills—native speakers preferred
- Hands-on developer and skilled React engineer
- Experience as a teacher, tutor, or mentor
- Experience as a technical writer or content creator
- Good product design sensibilities
- Basic design skills

### Nice to have (but not required)

- Great product design sensibilities
- Good design skills
- Experience in open-source
- Experience with design systems
- Experience with MUI products
- Experience with public speaking
- Experience creating video content
- Experience in community building (online or in person)

## Benefits and compensation

Competitive compensation depending on the profile and location.
We are ready to pay top market rates for a person who can clearly exceed the role's expectations.
You can find the other perks & benefits on the [careers](https://mui.com/careers/#perks-and-benefits) page.

## How to apply

[Apply now for this position 📮](https://jobs.ashbyhq.com/MUI/28287eeb-88d2-465f-96d7-e7fd99fabd7d/application?utm_source=ZNRrPGBkqO)

Don't meet every requirement?
Apply anyway!
Research shows that certain folks are less likely to apply for a role than others [unless they meet 100%](https://hbr.org/2014/08/why-women-dont-apply-for-jobs-unless-theyre-100-qualified) of the outlined qualifications.
If this role excites you, we want to hear from you.
We'd love for you to share the unique skills, passion, and experience you could bring to MUI.
