# Head of Operations

<p class="description">You will take ownership of designing, implementing, and overseeing most of the business operations to support MUI's growth.</p>

## Details of the role

- **Location**: Remote (preference for UTC-6 to UTC+5).
- **Type of work**: Full-time (contractor or employee [depending on circumstances](https://mui-org.notion.site/Hiring-FAQ-64763b756ae44c37b47b081f98915501#494af1f358794028beb4b7697b5d3102)).
- We're a **remote** company, operating mostly asynchronously.

## The company

MUI's story began in 2014 with Material UI, the most successful React implementation of Google's Material Design.
Today, Material UI stands as one of the most popular open-source libraries on GitHub and has paved the way for the fully-fledged startup known as MUI (founded in 2019), which now boasts an ever-expanding ecosystem of React UI products.
We're a company of 35+ people as of early 2024, and we're growing.

## The products

MUI is best known for our flagship product, Material UI—but this is just one of three core component libraries we maintain.
Base UI is our headless component library, and Joy UI is a sister library to Material UI that implements our own in-house Joy Design system.
We also host Design Kits and pre-built Templates.

Beyond the core libraries, MUI X offers advanced components like the Data Grid, Date and Time Pickers, and Charts, for more complex user interactions and data visualization needs.

We're also making ambitious moves to incorporate our full suite of components into Toolpad, a low-code admin builder tool for assembling full-stack apps faster than ever.

Learn more about MUI's products in this blog post: [An introduction to the MUI ecosystem](https://mui.com/blog/mui-product-comparison/).

## The culture

MUI is a fully remote company with a team that spans the globe.
The majority of our work is asynchronous, and we rely on written communication to collaborate.
We're radically transparent: nearly all of our work happens in public.
Each contributor has the freedom to decide how and when they work, and that work is primarily self-directed: it's your responsibility to define and complete your own tasks in a timely manner.

For additional details about the culture, you can check our [careers](https://mui.com/careers/) and [about](https://mui.com/about/) pages and also our [public Handbook](https://mui-org.notion.site/Handbook-f086d47e10794d5e839aef9dc67f324b).

## Why we're hiring

We have found market fit but we increasingly don't have the tools (in the broad sense) necessary to keep up with the requests from our users.
Up to recently, the founders of MUI were the only ones to work on business operations.
There is now a tiny team of two people working to support the operations needs.
But this isn't enough, the department is increasingly a bottleneck in growing the company.
We are looking for a Head of Operations to take ownership of designing, implementing, and overseeing most of the business operations to support MUI's growth.

Overall, both our open-source community and our premium products are growing fast.
We need talented people to keep up with the demands of our exigent community!

### Why this is interesting

Our approach to business operations is centered around operational excellence.
It involves relying on automation and writing custom code where necessary.
We are even building a product dedicated to improving internal tools for companies: https://mui.com/toolpad/ which we increasingly rely on internally.
You will likely use it a lot to improve processes.

Our products empower React developers to build awesome applications faster – we see millions of developers on MUI's docs every year, one million a month.

## The role

### Key responsibilities

Depending on the day, you'll:

- Oversee and manage the day-to-day operations of the company, including finance, IT, support, and legal.
- Lead and manage the operations team, including recruiting, training, and developing team members.
- Build and develop KPI dashboards (writing code if necessary) to be able to measure business health and performance.
- Work on keeping the financial model up to date and on accurate forecasts.
- Figuring out what to work on: working with the CEO and other leadership team members to identify and prioritize key initiatives and projects.
- Support the CEO for investor relations and fundraising.
- Implement a replacement to Google Group to scale email notifications (we use emails for the tasks of the ops team).
- Work toward SOC 2 certification.
- Migrate from Sendinblue to SendGrid.
- Oversee our US flip.
- Develop and implement strategies to support the growth and success of the company
- Create new [Toolpad apps](https://mui.com/toolpad/) to streamline the operations (could require some SQL & JavaScript skills).

## Who we're looking for

### Required

- Obsessive over the details, aiming for inbox zero.
- JavaScript & SQL code proficiency as a lot of our operations rely on it.
- Excellent written and verbal communication skills.
- Demonstrable competency in strategic planning and business development.
- Strong analytical, and problem-solving skills, with the ability to make data-driven decisions.
- A high sense of curiosity, enjoying self-learning to get things done. You are [versatile](https://review.firstround.com/the-adaptable-leader-is-the-new-holy-grail-become-one-hire-one).
- Excited about the ambiguity of an entrepreneurial, growing company, and able to juggle many projects and responsibilities.
- Bachelor's degree in a related field (for example computer science, business management).
- 1+ year of experience in a similar role.

### Nice to have (but not required)

- 3+ years of experience in a similar role.

## Benefits and compensation

Competitive compensation depending on the profile and location.
We are ready to pay top market rates for a person who can clearly exceed the role's expectations.
You can find the other perks & benefits on the [careers](https://mui.com/careers/#perks-and-benefits) page.

## How to apply

[Apply now for this position 📮](https://jobs.ashbyhq.com/MUI/86ab11dc-0320-4e14-9b5b-7c8b3fb5bb71/application?utm_source=ZNRrPGBkqO)

Don't meet every requirement?
Apply anyway!
Research shows that certain folks are less likely to apply for a role than others [unless they meet 100%](https://hbr.org/2014/08/why-women-dont-apply-for-jobs-unless-theyre-100-qualified) of the outlined qualifications.
If this role excites you, we want to hear from you.
We'd love for you to share the unique skills, passion, and experience you could bring to MUI.
