# Product Engineer — Store

<p class="description">You will lead the technical, product, and operational development of the store.</p>

## Details of the role

- **Location**: Remote (preference for UTC-6 to UTC+5).
- **Type of work**: Full-time (contractor or employee [depending on circumstances](https://mui-org.notion.site/Hiring-FAQ-64763b756ae44c37b47b081f98915501#494af1f358794028beb4b7697b5d3102)).
- **Level**: [IC4 or above](https://mui-org.notion.site/Leveling-at-MUI-5c30f9bfe65149d697f346447cef9db1).
- We're a **remote** company, we prefer asynchronous communication over meetings.

## The company

MUI's story began in 2014 with Material UI, the most successful React implementation of Google's Material Design.
Today, Material UI stands as one of the most popular open-source libraries on GitHub and has paved the way for the fully-fledged startup known as MUI (founded in 2019), which now boasts an ever-expanding ecosystem of React UI products.
We're a company of 35+ people as of early 2024, and we're growing.

## The products

MUI is best known for our flagship product, Material UI—but this is just one of three core component libraries we maintain.
Base UI is our headless component library, and Joy UI is a sister library to Material UI that implements our own in-house Joy Design system.
We also host Design Kits and pre-built Templates.

Beyond the core libraries, MUI X offers advanced components like the Data Grid, Date and Time Pickers, and Charts, for more complex user interactions and data visualization needs.

We're also making ambitious moves to incorporate our full suite of components into Toolpad, a low-code admin builder tool for assembling full-stack apps faster than ever.

Learn more about MUI's products in this blog post: [An introduction to the MUI ecosystem](https://mui.com/blog/mui-product-comparison/).

## The culture

MUI is a fully remote company with a team that spans the globe.
The majority of our work is asynchronous, and we rely on written communication to collaborate.
We're radically transparent: nearly all of our work happens in public.
Each contributor has the freedom to decide how and when they work, and that work is primarily self-directed: it's your responsibility to define and complete your own tasks in a timely manner.

For additional details about the culture, you can check our [careers](https://mui.com/careers/) and [about](https://mui.com/about/) pages and also our [public Handbook](https://mui-org.notion.site/Handbook-f086d47e10794d5e839aef9dc67f324b).

## Why we're hiring

The development and operations of the store are currently almost exclusively run by the executive team of the company (the co-founders).
This team doesn't have enough bandwidth, the store doesn't receive the care it deserves.
You will be responsible to step up and carry forward the development of the store on new fronts.

Overall, both our open-source community and our premium products are growing fast.
We need talented people to keep up with the demands of our exigent community!

### Why this is interesting

You will get the opportunity to work on many different topics.

Our products empower React developers to build awesome applications faster – we see millions of developers on MUI's docs every year, one million a month.

## The role

### Key responsibilities

Depending on the day, you'll:

- Take initiatives to grow the sales of the templates
- Define the product direction
- Review new items submitted by the contributors to be hosted on the marketplace
- Fix root problems raised by store customers on the support channels
- Take care of operational needs, for example automate payouts, create sales reports

### Here are a few initiatives you might work on

Tasks that you might work on once you join:

- Explore ways to provide a theme builder/sell themes on the platform that deeply integrate with MUI Core and the documentation.
- Develop the SEA & SEO strategy, create new blog posts, try retargeting, Google Ads, etc.
- Improve the fulfillment workflow of MUI X Pro & Premium.
- Develop a Figma plugin & backend to push [MUI for Figma](https://mui.com/store/items/figma-react/) to reduce the collaboration friction between designers and developers.
- Add a search page to scale the hosting to more items from contributors.
- Revamp the design of the store to match the new brand of mui.com.
- Migrate the store from Gatsby to Next.js or Remix. Gatsby was introduced at a point in time when it had more downloads than Next.js. Our CEO has experience with Next.js since 2017 but wanted to ensure that MUI was supporting Gatsby well too.
  This requirement [is no longer relevant](https://npm-stat.com/charts.html?package=next&package=gatsby), and since the DX of Next.js is significantly better, time to migrate.

## Who we're looking for

We're looking for someone with strong development skills, and more important than specific technical skills a strong problem solver who loves to learn new things. Details matter to you.
This role is perfect for you if you are curious, have tenacity, enjoy tacking risk, and care about design.
You are a [manager of one](https://signalvnoise.com/posts/1430-hire-managers-of-one).

### Required

- **Expertise in modern JavaScript ecosystem.** The store is currently build on WooCommerce so expertise in WordPress/PHP could help. Our backend technology of choice is Node.js.
- **A track record of demonstrating an eye for product and solving real-world user problems**. If you have a knack for solving problems at the root cause, finding boring solutions, we want you on our team.
- **Strong written and verbal communication skills**.
  As part of the team, you'll interface both directly and indirectly with community members and enterprise customers, and contribute to user documentation. Clear communication is fundamental in creating intuitive and compelling resources.
- **Ability to dive into complex problems**.
  You should be able to quickly assess, understand, and iterate upon aspects of our codebase.
- **Ready and willing to ask and answer questions**.
  If you're comfortable saying you're unsure, asking for help; but equally reaching out to assist others, you'll be an incredible addition to our team. We thrive because of continuous learning. First-time mistakes should be celebrated, not blamed.
- **Avoid monolithic deliverables**.
  You scope and stage your work into well-defined milestones to ship.

### Nice to have (but not required)

- **Has or is pursuing a business side project**. You owned a side project generating revenues on the side of your full-time job. You were doing whatever was necessary to solve people's pain.

## Benefits and compensation

Competitive compensation depending on the profile and location.
We are ready to pay top market rates for a person who can clearly exceed the role's expectations.
You can find the other perks & benefits on the [careers](https://mui.com/careers/#perks-and-benefits) page.

## How to apply

[Apply now for this position 📮](https://jobs.ashbyhq.com/MUI/e641bac3-5538-4ec8-8d73-eaa1a03704d6/application?utm_source=ZNRrPGBkqO)

Don't meet every requirement?
Apply anyway!
Research shows that certain folks are less likely to apply for a role than others [unless they meet 100%](https://hbr.org/2014/08/why-women-dont-apply-for-jobs-unless-theyre-100-qualified) of the outlined qualifications.
If this role excites you, we want to hear from you.
We'd love for you to share the unique skills, passion, and experience you could bring to MUI.
