# Product Manager

<p class="description">We are looking for a product manager to guide our roadmap and build a great product.</p>

## Details of the role

- **Location**: Remote (preference for UTC-6 to UTC+5).
- **Type of work**: Full-time (contractor or employee [depending on circumstances](https://mui-org.notion.site/Hiring-FAQ-64763b756ae44c37b47b081f98915501#494af1f358794028beb4b7697b5d3102)).
- We're a **remote** company, we prefer asynchronous communication over meetings.

## The company

MUI's story began in 2014 with Material UI, the most successful React implementation of Google's Material Design.
Today, Material UI stands as one of the most popular open-source libraries on GitHub and has paved the way for the fully-fledged startup known as MUI (founded in 2019), which now boasts an ever-expanding ecosystem of React UI products.
We're a company of 35+ people as of early 2024, and we're growing.

## The products

MUI is best known for our flagship product, Material UI—but this is just one of three core component libraries we maintain.
Base UI is our headless component library, and Joy UI is a sister library to Material UI that implements our own in-house Joy Design system.
We also host Design Kits and pre-built Templates.

Beyond the core libraries, MUI X offers advanced components like the Data Grid, Date and Time Pickers, and Charts, for more complex user interactions and data visualization needs.

We're also making ambitious moves to incorporate our full suite of components into Toolpad, a low-code admin builder tool for assembling full-stack apps faster than ever.

Learn more about MUI's products in this blog post: [An introduction to the MUI ecosystem](https://mui.com/blog/mui-product-comparison/).

## The culture

MUI is a fully remote company with a team that spans the globe.
The majority of our work is asynchronous, and we rely on written communication to collaborate.
We're radically transparent: nearly all of our work happens in public.
Each contributor has the freedom to decide how and when they work, and that work is primarily self-directed: it's your responsibility to define and complete your own tasks in a timely manner.

For additional details about the culture, you can check our [careers](https://mui.com/careers/) and [about](https://mui.com/about/) pages and also our [public Handbook](https://mui-org.notion.site/Handbook-f086d47e10794d5e839aef9dc67f324b).

## Why we're hiring

Our mission is to empower as many people as possible to build great UIs, faster.
The faster and simpler it is, and the broader the audience that can create custom UIs, the better.
We believe that the best way to improve on these dimensions is to eliminate [80%](https://www.youtube.com/watch?v=GnO7D5UaDig&t=2451s) of the code that has to be written: low-code.

Overall, both our open-source community and our premium products are growing fast.
We need talented people to keep up with the demands of our exigent community!

### Why this is interesting

Our products empower React developers to build awesome applications faster – we see millions of developers on MUI's docs every year, one million a month.

But providing React components isn't enough.
In our [last Developer Survey](https://mui.com/blog/2021-developer-survey-results/), we learned that the majority of our audience are full-stack developers.
They are looking for ways to move faster.
They are working on a couple of new projects every year, and where the integration between the UI and the database is key.

You will initiate the exploration of a bold new product vertical.

## The role

### Key responsibilities

Depending on the day, you'll:

- You will coordinate with the engineering to ensure that the product being delivered at each iteration solves the problem.
  This involves growing a deep understanding of our technical choices and constraints.
- You will drive the growth of the product by owning KPIs.
- You will grow and cultivate a deep understanding of the problems that developers have when they create simple applications (for example admins, prototypes). This means that you will observe and reach out to the community, run research interviews and share your insights with the team.
- You will keep a close eye on feature requests, issues, and general improvements, to curate opportunities based on our strategy.
- You will build a strategy for your product area and contribute to the overall product strategy, for example establishing a go-to-market strategy.
- You will assess the impact of initiatives through telemetry data and qualitative feedback to help us develop our understanding further, and decide on the next steps.

## Who we're looking for

### Required

- 3+ years experience as Product Manager or closely related roles such as Product Owner, Program Manager, or Solutions Architect.
- Able to switch between the big picture and detailed view multiple times a day.

### Nice to have (but not required)

- Experience building developer tools.
- Experience working with open-source and having interacted with open-source communities.

## Benefits and compensation

Competitive compensation depending on the profile and location.
We are ready to pay top market rates for a person who can clearly exceed the role's expectations.
You can find the other perks & benefits on the [careers](https://mui.com/careers/#perks-and-benefits) page.

## How to apply

[Apply now for this position 📮](https://jobs.ashbyhq.com/MUI/__ID__/application?utm_source=ZNRrPGBkqO)

Don't meet every requirement?
Apply anyway!
Research shows that certain folks are less likely to apply for a role than others [unless they meet 100%](https://hbr.org/2014/08/why-women-dont-apply-for-jobs-unless-theyre-100-qualified) of the outlined qualifications.
If this role excites you, we want to hear from you.
We'd love for you to share the unique skills, passion, and experience you could bring to MUI.
