# React Community Engineer — X (future role)

<p class="description">You will provide guidance to the community and solve their struggle, working primarily in the advanced components team.</p>

## Details of the role

- **Location**: Remote (preference for UTC-6 to UTC+5).
- **Type of work**: Full-time (contractor or employee [depending on circumstances](https://mui-org.notion.site/Hiring-FAQ-64763b756ae44c37b47b081f98915501#494af1f358794028beb4b7697b5d3102)).
- **Level**: [IC4 or above](https://mui-org.notion.site/Leveling-at-MUI-5c30f9bfe65149d697f346447cef9db1).
- We're a **remote** company, we prefer asynchronous communication over meetings.

## The company

MUI's story began in 2014 with Material UI, the most successful React implementation of Google's Material Design.
Today, Material UI stands as one of the most popular open-source libraries on GitHub and has paved the way for the fully-fledged startup known as MUI (founded in 2019), which now boasts an ever-expanding ecosystem of React UI products.
We're a company of 35+ people as of early 2024, and we're growing.

## The products

MUI is best known for our flagship product, Material UI—but this is just one of three core component libraries we maintain.
Base UI is our headless component library, and Joy UI is a sister library to Material UI that implements our own in-house Joy Design system.
We also host Design Kits and pre-built Templates.

Beyond the core libraries, MUI X offers advanced components like the Data Grid, Date and Time Pickers, and Charts, for more complex user interactions and data visualization needs.

We're also making ambitious moves to incorporate our full suite of components into Toolpad, a low-code admin builder tool for assembling full-stack apps faster than ever.

Learn more about MUI's products in this blog post: [An introduction to the MUI ecosystem](https://mui.com/blog/mui-product-comparison/).

## The culture

MUI is a fully remote company with a team that spans the globe.
The majority of our work is asynchronous, and we rely on written communication to collaborate.
We're radically transparent: nearly all of our work happens in public.
Each contributor has the freedom to decide how and when they work, and that work is primarily self-directed: it's your responsibility to define and complete your own tasks in a timely manner.

For additional details about the culture, you can check our [careers](https://mui.com/careers/) and [about](https://mui.com/about/) pages and also our [public Handbook](https://mui-org.notion.site/Handbook-f086d47e10794d5e839aef9dc67f324b).

## Why we're hiring

We need a Community Engineer to solve friction points of users.
We face challenges on multiple fronts:

- As a result of this growth, we (will) have more users questions and feedback coming in than ever before.
- The commercial version of the library is growing, but our community of developers is still small and has a reduced incentive to contribute compared to the community plan.
- Software engineers at MUI are tasked with doing support, however, they could benefit from the help of a dedicated person in the company, for instance to improve the workflows and tooling.
- The MUI X Premium plan will offer a technical advisor service, we need a Community Engineer to help deliver it.

Overall, both our open-source community and our premium products are growing fast.
We need talented people to keep up with the demands of our exigent community!

## The role

### Why this is interesting

You will be a key member of the Developer Experience's team and will directly impact customer satisfaction and success.
You will troubleshoot and depending on your bandwidth also fix complex issues related to MUI.
At MUI a Community Engineer is considered a developer, it's a person that enjoys optimizing what already exists but is also eager to help our users with features that are requested by the community.

Our products empower React developers to build awesome applications faster – we see millions of developers on MUI's docs every year, one million a month.

### Key responsibilities

You will own the following responsibilities:

- **Build product knowledge**. You will continually research and learn the current and future best practices of using MUI.
- **Resolve users' issues**. You will solve these issues at two levels:
  - On the surface, you will answer developers on GitHub, Zendesk, X, email, Slack.
  - At the root, you will create/update the documentation, fix bugs in collaboration with the relevant developer, implement community driven features and more.
- **Provide feedback**. You will work alongside product managers to define and shape the product goals, roadmap, priorities, and strategy based on your frontline knowledge of customer needs.
- **Operations**.
  - You will establish key support metrics and identify how best to measure them.
  - You will establish a workflow to reduce 'time to response' and 'time to fix' that can scale to multiple team members.
  - You will identify where internal tooling might be developed or obtained to improve support efficiency.

For the right candidate:

- Working with the Leadership to construct and execute a hiring plan to grow the community team.

Depending on the day, you'll:

- **You'll be interacting with the users** on a regular basis, handling inbound support and feature requests (every developer helps with developer requests).
- **Reduce friction**.
  A large amount of the work on MUI is reducing friction and making it easier to use.
  This might involve careful API design, identifying and fixing top bugs, creating easier-to-understand error messages, and writing documentation and blog posts about features you ship.
- **Collaborate with the community**.
  Many small, as well as meaningful fixes and features, have been contributed by the community. Your role is to draw the best out of the community — to inspire those across the world to create and contribute through your reviews of their issues and pull requests.
- **Experiment and play**. Great, unexpected features and heisenbug fixes have come from a number of sources — relentlessly methodical processes of elimination, free-flowing team collaboration, inspiration by adjacent libraries and projects, and difficult-to-explain individual strokes of brilliance. Whatever your preferred style is for creating new things that others might not have thought of, you'll find a welcome home on the team.
- **Ship. Early and often**. You'll iterate and ship frequently.
  You'll have a real impact on the end-user experience and you'll love working on a team that builds stunning UIs and prioritizes delivering real user value as often as possible.

## Who we're looking for

We're looking for someone with strong front-end skills. More important than specific technical skills though is that you're a strong problem solver who loves to learn. Details matter to you.

### Required

- **Expertise in the modern JavaScript ecosystem**.
  MUI's open-source projects are built on the shoulders of giants, making use of technologies such as ES2021, TypeScript, Node.js, React, Next.js, webpack, and Babel.
- **A track record of demonstrating an eye for product and solving real-world user problems**. If you have a knack for solving problems at the root cause, shipping beautiful user interfaces and intuitive APIs, we want you on our team.
- **Strong written and verbal communication skills**.
  As part of the team, you'll interface both directly and indirectly with community members and enterprise customers, and contribute to user documentation. Clear communication is fundamental in creating intuitive and compelling resources.
- **Ability to dive into complex problems**.
  You should be able to quickly assess, understand, and iterate upon aspects of our codebase.
- **Ready and willing to ask and answer questions**.
  If you're comfortable saying you're unsure, asking for help; but equally reaching out to assist others, you'll be an incredible addition to our team. We thrive because of continuous learning. First-time mistakes should be celebrated, not blamed.
- **Avoid monolithic deliverables**.
  You scope and stage your work into well-defined milestones to ship.
- **Past work with front-end infrastructure**.
  Perhaps you've created your company's design system, written a Babel plugin, or written complex React components.
  It would be great if you could address this in your cover letter!

### Nice to have (but not required)

- **You've contributed to a design system before**.
  You have worked on enterprise components in the past, maybe for internal use in your company.
  You have built complex and advanced features while making sure the accessibility was fully functional.
- **You've maintained an active repository before**.
  Maybe you've helped maintain a popular open-source repository, or perhaps you've worked on internal repositories that saw contributions from multiple teams.
  Previous experience with highly active repository workflows is a definite plus for this role.
- **You have contributed code**. A history of contributing to MUI's open-source projects is a plus.

## Benefits and compensation

Competitive compensation depending on the profile and location.
We are ready to pay top market rates for a person who can clearly exceed the role's expectations.
You can find the other perks & benefits on the [careers](https://mui.com/careers/#perks-and-benefits) page.

## How to apply

[Apply now for this position 📮](https://jobs.ashbyhq.com/MUI/e362a14c-6674-4ac9-8eee-bcf44a8767c8/application?utm_source=ZNRrPGBkqO)

Don't meet every requirement?
Apply anyway!
Research shows that certain folks are less likely to apply for a role than others [unless they meet 100%](https://hbr.org/2014/08/why-women-dont-apply-for-jobs-unless-theyre-100-qualified) of the outlined qualifications.
If this role excites you, we want to hear from you.
We'd love for you to share the unique skills, passion, and experience you could bring to MUI.
