# Senior Designer

<p class="description">You will be responsible for pushing MUI's component design bar higher.</p>

## Details of the role

- **Location**: Remote (preference for UTC-6 to UTC+5).
- **Type of work**: Full-time (contractor or employee [depending on circumstances](https://mui-org.notion.site/Hiring-FAQ-64763b756ae44c37b47b081f98915501#494af1f358794028beb4b7697b5d3102)).
- **Level**: [IC3 or above](https://mui-org.notion.site/Design-levels-aa01996ca7e0481e80479ad47c8f28a4).
- We're a **remote** company, operating mostly asynchronously (written communication over meetings).

## The company

MUI's story began in 2014 with Material UI, the most successful React implementation of Google's Material Design.
Today, Material UI stands as one of the most popular open-source libraries on GitHub and has paved the way for the fully-fledged startup known as MUI (founded in 2019), which now boasts an ever-expanding ecosystem of React UI products.
We're a company of 35+ people as of early 2024, and we're growing.

## The products

MUI is best known for our flagship product, Material UI—but this is just one of three core component libraries we maintain.
Base UI is our headless component library, and Joy UI is a sister library to Material UI that implements our own in-house Joy Design system.
We also host Design Kits and pre-built Templates.

Beyond the core libraries, MUI X offers advanced components like the Data Grid, Date and Time Pickers, and Charts, for more complex user interactions and data visualization needs.

We're also making ambitious moves to incorporate our full suite of components into Toolpad, a low-code admin builder tool for assembling full-stack apps faster than ever.

Learn more about MUI's products in this blog post: [An introduction to the MUI ecosystem](https://mui.com/blog/mui-product-comparison/).

## The culture

MUI is a fully remote company with a team that spans the globe.
The majority of our work is asynchronous, and we rely on written communication to collaborate.
We're radically transparent: nearly all of our work happens in public.
Each contributor has the freedom to decide how and when they work, and that work is primarily self-directed: it's your responsibility to define and complete your own tasks in a timely manner.

For additional details about the culture, you can check our [careers](https://mui.com/careers/) and [about](https://mui.com/about/) pages and also our [public Handbook](https://mui-org.notion.site/Handbook-f086d47e10794d5e839aef9dc67f324b).

## Why we're hiring

We are aiming to make high-end design accessible to the many, empowering developers that lack access to a designer as well as saving time for designers with a source they can trust.
[According to our last survey](https://mui.com/blog/2021-developer-survey-results/#what-are-your-most-important-criteria-for-choosing-a-ui-library), the quality of the design execution (UX & UI) is the most important criteria used by developers & designers to pick their next UI library.

Overall, both our open-source community and our premium products are growing fast.
We need talented people to keep up with the demands of our exigent community!

### Why this is interesting

Our products empower React developers to build amazing applications faster – we see millions of developers on MUI's docs every year, one million a month.

However, despite Material UI – our biggest library – being [the leading](https://tsh.io/state-of-frontend/#over-the-past-year-which-of-the-following-design-systems-was-your-favorite-go-to-solution) UI design system in the frontend space, its adoption is only at 25%.
More importantly, our challenges go way beyond the ones of design systems.

We envision a future where MUI becomes the default toolkit for web developers to create UIs.
It's why we've been expanding our offering with Joy UI, Base UI, and Toolpad.
Design is foundational to achieving this goal.

## The role

Designers at MUI are essentially _team leaders_.
That means you'll be working closely with your engineering lead counterpart to shape work and scope targeting a set of problems revolving around our component area, either on MUI Core or MUI X (to be further defined).

As our [design philosophy](https://mui-org.notion.site/Design-philosophy-bdbef60d6fad4134a43870df3e452ebc) states, you'll be conducting and guiding the whole team, making sure everything we do is adding a special design spice that only you can add.
We imagine a world where design execution is a definitive product differentiator.

### What you'll do in your first month

- Understand how your role fits into the organization and get acquainted with team members and processes
- Learn about MUI's products, business, goals, and how users experience the MUI ecosystem
- Make your first contribution to either MUI Core or MUI X on an approachable, simple problem

### What you'll do in your first 3 months

- Conduct one-on-one user interviews with community members
- Review and give feedback to work from other designers on the team
- Understand the MUI Core and MUI X library patterns to improve existing components' UX & UI
- Open your first PR improving documentation or demos

### What you'll do in your first 6 months

- Design a new component for one of the MUI Core libraries from scratch in partnership with a developer
- Design new templates for either Joy UI or Material UI and support their implementation
- Review new Figma Design Kit versions and coordinate their next release

### What you'll have done in your first year

Aside from all of the above, by the time you complete your first year, you should be able to:

- Proactively identify improvement opportunities across MUI's ecosystem
- Help your team structure and follow a plan to tackle user pain points that you help to discover
- Foster an even more design-oriented, user-centered culture at MUI
- Contribute in a code capacity more confidently, with the ability to tweak and improve your own designs

## Who we're looking for

If you get excited by thinking about design systems, high-level of craftsmanship, accessible components, and joyful experiences, then we're looking for you!

We're looking for designers who are generalists, meaning they can navigate from very high-level product strategy discussions to low-level implementation work.

As a company that develops code-based products, it's important that you have a grasp of development to be effective.
Concretely, that means you can at least picture how a given CSS snippet looks like just by reading it.
Being able to contribute to the codebase yourself, open pull requests, and improve documentation or components is very valuable.

We strongly believe designers should code to ensure the level of detail they've wished for is really being implemented.
So, if you're this designer, either already able to code or growing in this direction, we're looking for you.

### Other skills you should have

- **Excellent written and verbal communication skills.** You will communicate both in writing and verbally with our globally-distributed team, community members, and enterprise customers. English is the primary language we interact in.
- **Experience building and evaluating UI/UX.** You can design attractive UIs with well-thought-out interaction patterns that solve practical user problems.
- **Design systems experience.** You have previously worked on or contributed to the creation of a design system. You are meticulous about component APIs, standards, and organization.
- **Relative development autonomy.** Ability to read HTML/JSX and CSS is a requirement. Being able to code and contribute to the codebase would be a significant advantage, but isn't required for the role.

### It would be nice if you had but it isn't required

- **Past experience with open-source projects.** You understand the unique dynamics of products in an open-source environment as well as common challenges that arise.

## Benefits and compensation

We are ready to pay competitive, top market rates, for a person that can clearly exceed the role's expectations.
Therefore, we consider profile and location.
You can find the other perks & benefits on the [careers](https://mui.com/careers/#perks-and-benefits) page.

## Interview steps

Here's a brief overview of how this role's process will be carried through:

- **Introduction call** (20 to 25 min): A short call to quickly introduce each other.
- **Career deep dive** (40 to 60 min ⎯ with a designer): We'll go through your career a bit more in-depth and will be interested in understanding your trajectory up to the point where you've applied to this role.
- **Comparable experience review** (40 to 60 min ⎯ with a designer, product manager or tech lead): We'll deep dive into a presentation of relevant past experiences to understand your approach to problem-solving and design.
- **Conversation with the CEO** (60 min): A quick call so you get to know each other, and talk about vision, future, history, etc.

We like to encourage candidates to also see all of these conversations as opportunities for you to interview us as well.
It's highly encouraged to bring whatever questions you see fit to make sure we are also a great role for you.

## How to apply

[Apply now for this position 📮](https://jobs.ashbyhq.com/MUI/4ea9d324-3350-48d5-bfab-706ebfc23ed2/application?utm_source=ZNRrPGBkqO)

Don't tick every bullet? **Apply anyway!** Research shows that certain folks are less likely to apply for a role than others [unless they meet 100%](https://hbr.org/2014/08/why-women-dont-apply-for-jobs-unless-theyre-100-qualified) of the outlined qualifications.
If this role excites you, we want to hear from you. We'd love for you to share the unique skills, passion, and experience you could bring to MUI.
