# Staff UI Engineer — Base UI

<p class="description">Research, build, document, and ship high-quality, unstyled UI components with a focus on a11y.</p>

## Details of the role

- **Location**: Remote (preference for UTC-6 to UTC+5).
- **Type of work**: Full-time (contractor or employee [depending on circumstances](https://mui-org.notion.site/Hiring-FAQ-64763b756ae44c37b47b081f98915501#494af1f358794028beb4b7697b5d3102)).
- **Level**: [IC5 or above](https://mui-org.notion.site/Leveling-at-MUI-5c30f9bfe65149d697f346447cef9db1).

## The company

MUI's story began in 2014 with Material UI, the most successful React implementation of Google's Material Design.
Today, Material UI stands as one of the most popular open-source libraries on GitHub and has paved the way for the fully-fledged startup known as MUI (founded in 2019), which now boasts an ever-expanding ecosystem of React UI products.
We're a company of 35+ people as of early 2024, and we're growing.

## The products

MUI is best known for our flagship product, Material UI—but this is just one of three core component libraries we maintain.
Base UI is our headless component library, and Joy UI is a sister library to Material UI that implements our own in-house Joy Design system.
We also host Design Kits and pre-built Templates.

Beyond the core libraries, MUI X offers advanced components like the Data Grid, Date and Time Pickers, and Charts, for more complex user interactions and data visualization needs.

We're also making ambitious moves to incorporate our full suite of components into Toolpad, a low-code admin builder tool for assembling full-stack apps faster than ever.

Learn more about MUI's products in this blog post: [An introduction to the MUI ecosystem](https://mui.com/blog/mui-product-comparison/).

## The culture

MUI is a fully remote company with a team that spans the globe.
The majority of our work is asynchronous, and we rely on written communication to collaborate.
We're radically transparent: nearly all of our work happens in public.
Each contributor has the freedom to decide how and when they work, and that work is primarily self-directed: it's your responsibility to define and complete your own tasks in a timely manner.

For additional details about the culture, you can check our [careers](https://mui.com/careers/) and [about](https://mui.com/about/) pages and also our [public Handbook](https://mui-org.notion.site/Handbook-f086d47e10794d5e839aef9dc67f324b).

## Why we're hiring

The Base UI team is just starting to take shape now, and we have big goals for the next few years. We need experienced people to work alongside excellent UI engineers and designers, in an IC capacity, to research, spec, build, document, and ship high-quality, unstyled UI components with a focus on a11y.

Overall, both our open-source community and our premium products are growing fast.
We need talented people to keep up with the demands of our exigent community!

### Why this is interesting

Our products empower React developers to build awesome applications faster – we see millions of developers on MUI's docs every year, one million a month. We're planning to invest heavily in Base UI this year and into the future. Our goal is to make Base UI one the best unstyled UI libs available, and in the process, help millions of developers build more accessible products.

## The role

### Key responsibilities

Depending on the day, you'll:

- Build UI components with React and TypeScript.
- Perform code reviews and help to maintain a high bar for code quality.
- Test Base UI components on various devices, browsers, platforms, and screen readers.
- Research a11y requirements for UI components.
- Contribute to component API design decisions and architecture.
- Contribute to Base UI documentation.
- Help out with community support on GitHub and Discord.

## Who we're looking for

### Required

- **Expertise with the modern JavaScript ecosystem**. Base UI is built on modern front-end technologies like TypeScript, Node.js, React, Next.js, webpack, and Babel. Working knowledge of these technologies is critical.
- **Expertise with CSS.** Deep knowledge of the functional aspects of CSS will be required.
- **Familiarity with a11y requirements.** We are looking for someone familiar with ARIA requirements, who cares about building accessible UI, and wants to make the web a more accessible place.
- **An eye for detail.** We appreciate people who sweat the details. People who go above and beyond to make interfaces fast, accessible, beautiful, and delightful.
- **Experience shipping production code in a team setting.** We are looking for someone with multiple years of experience working on production code.
- **Strong written and verbal communication skills**. As part of the team, you'll communicate both directly and indirectly with community members and enterprise customers, and contribute to user documentation. Clear communication is important in creating intuitive and compelling resources.

### Nice to have (but not required)

- **Experience working remotely.** Experience is not necessarily mandatory, but remote work can be a different challenge sometimes, so some experience would be helpful.
- **Experience working with design systems**. We are not looking for visual designers, but familiarity with the needs of design system maintainers would be helpful.
- **Experience contributing to OSS**. MUI is all about open-source software, so OSS experience would be awesome.

## Benefits and compensation

Competitive compensation depending on the profile and location.
We are ready to pay top market rates for a person who can clearly exceed the role's expectations.
You can find the other perks & benefits on the [careers](https://mui.com/careers/#perks-and-benefits) page.

## How to apply

[Apply now for this position 📮](https://jobs.ashbyhq.com/MUI/3094f65a-0144-4bd2-ba5b-6b9c61040858/application?utm_source=ZNRrPGBkqO)

Don't meet every requirement?
Apply anyway!
Research shows that certain folks are less likely to apply for a role than others [unless they meet 100%](https://hbr.org/2014/08/why-women-dont-apply-for-jobs-unless-theyre-100-qualified) of the outlined qualifications.
If this role excites you, we want to hear from you.
We'd love for you to share the unique skills, passion, and experience you could bring to MUI.
